# vim: set filetype=spec:

%global debug_package %{nil}

Name: typst
Version: 0.13.1
Release: 2%{?dist}
Source: https://github.com/typst/typst/archive/refs/tags/v%{version}.tar.gz
Summary: new markup-based typesetting system that is powerful and easy to learn
License: Apache-2.0

#sudo dnf provides "/usr/lib64/pkgconfig/openssl.pc" "/usr/share/pkgconfig/openssl.pc"
BuildRequires: cargo
BuildRequires: git
BuildRequires: gzip
BuildRequires: openssl-devel
BuildRequires: cargo-rpm-macros >= 24

# Arch <https://gitlab.archlinux.org/archlinux/packaging/packages/typst>
Requires: alerque-libertinus-fonts
Requires: linux-libertine-biolinum-fonts
Requires: linux-libertine-fonts
Requires: linux-libertine-fonts-all
Requires: linux-libertine-mono-fonts
#Requires: texlive-libertine
#Requires: texlive-libertinegc
#Requires: texlive-libertinegc-doc
#Requires: texlive-libertinus
#Requires: texlive-libertinus-doc
#Requires: texlive-libertinus-fonts
#Requires: texlive-libertinus-otf
#Requires: texlive-libertinus-type1
#Requires: texlive-libertinust1math
#Requires: texlive-libertinust1math-doc

%description
Typst is a new markup-based typesetting system that is designed to be as powerful as LaTeX while being much easier to learn and use. Typst has:

- Built-in markup for the most common formatting tasks
- Flexible functions for everything else
- A tightly integrated scripting system
- Math typesetting, bibliography management, and more
- Fast compile times thanks to incremental compilation
- Friendly error messages in case something goes wrong


%prep
%autosetup
# (fetch+offline)
#cargo fetch --locked --target "$(rustc -vV | sed -n 's/host: //p')"


%build
p() { printf "\e[33m%s\e[0m\n" "$*"; }
hash="$(gunzip <%{_sourcedir}/v%{VERSION}.tar.gz | git get-tar-commit-id)"
export GEN_ARTIFACTS=artifacts/
export OPENSSL_NO_VENDOR=1
export TYPST_VERSION="%{VERSION} (${hash::8})"
p b.0 "$TYPST_VERSION"
%set_build_flags
C=(
	cargo
	build
	#-p typst-cli
	--release
	--all-features
	--locked
	#--offline # (fetch+offline)
)
"${C[@]}"


#%%check
#cargo test --workspace --frozen


# (mockSH)
# BB=/builddir/build/BUILD/typst-0.13.1-build/typst-0.13.1/
# BR=/builddir/build/BUILD/typst-0.13.1-build/BUILDROOT/
# cd $BB


%install

# where
p() { printf "\e[33m%s\e[0m\n" "$*"; }
p i.1 %{_sourcedir}
p i.2 $PWD
p i.3 %{buildroot}
p i.4 "$(umask) $(umask -S)"

# bin
mkdir -pv %{buildroot}%{_bindir} && cp -v target/release/%{NAME} $_/

# (cd)
cd crates/typst-cli/artifacts

# man
mkdir -pv %{buildroot}%{_mandir}/man1 && cp -v *.1 $_/

# completions
S=%{buildroot}%{_datadir}
mkdir -pv  $S/bash-completion/completions && cp -v %{NAME}.bash $_/%{NAME}
#elvish %{NAME}.elv
mkdir -pv $S/fish/vendor_completions.d && cp -v %{NAME}.fish $_/
#powershell _%{NAME}.ps1
mkdir -pv $S/zsh/site-functions && cp -v _%{NAME} $_/


%files
%{_bindir}/%{NAME}
%{_mandir}/man1
%{_datadir}/bash-completion
%{_datadir}/fish
%{_datadir}/zsh
%doc CITATION.cff CONTRIBUTING.md NOTICE README.md
%license LICENSE


%changelog
%autochangelog
